
from pyfileconf.io.file.load.lazy.pipeline import PipelineDictLoader

class PipelineDictInterface(PipelineDictLoader):

    def save(self):
        # TODO [#9]: write pipeline dict to file
        pass