
from pyfileconf.io.file.load.lazy.datadict import SpecificClassDictLoader

class SpecificClassInterface(SpecificClassDictLoader):

    def save(self):
        # TODO [#8]: write data dict to file
        pass